@@ -252,7 +252,8 @@ class BillingConductorClient(BaseClient):
         ClientToken: str = ...,
         Description: str = ...,
         Service: str = ...,
-        Tags: Mapping[str, str] = ...
+        Tags: Mapping[str, str] = ...,
+        BillingEntity: str = ...
     ) -> CreatePricingRuleOutputTypeDef:
         """
         Creates a pricing rule can be associated to a pricing plan, or a set of pricing
