@@ -71,7 +71,7 @@ ListPricingRulesPaginatorName = Literal["list_pricing_rules"]
 ListResourcesAssociatedToCustomLineItemPaginatorName = Literal[
     "list_resources_associated_to_custom_line_item"
 ]
-PricingRuleScopeType = Literal["GLOBAL", "SERVICE"]
+PricingRuleScopeType = Literal["BILLING_ENTITY", "GLOBAL", "SERVICE"]
 PricingRuleTypeType = Literal["DISCOUNT", "MARKUP"]
 BillingConductorServiceName = Literal["billingconductor"]
 ServiceName = Literal[
@@ -343,6 +343,7 @@ ServiceName = Literal[
     "sagemaker-featurestore-runtime",
     "sagemaker-runtime",
     "savingsplans",
+    "scheduler",
     "schemas",
     "sdb",
     "secretsmanager",
@@ -365,6 +366,7 @@ ServiceName = Literal[
     "ssm",
     "ssm-contacts",
     "ssm-incidents",
+    "ssmsap",
     "sso",
     "sso-admin",
     "sso-oidc",
